==> trilinos-12.6.2-1-x86_64.pkg.tar.xz: usr/include/KokkosClassic_DefaultNode_config.h <==
#ifndef TPETRACLASSIC_DEFAULTNODE_CONFIG_H
#define TPETRACLASSIC_DEFAULTNODE_CONFIG_H

// Tpetra's default Node type.
#define TPETRA_DEFAULTNODE Kokkos::Compat::KokkosOpenMPWrapperNode
// For backwards compatibility ONLY.
#define KOKKOSCLASSIC_DEFAULTNODE TPETRA_DEFAULTNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Cuda.
/* #undef HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_CUDAWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::OpenMP.
#define HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_OPENMPWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Threads.
/* #undef HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_THREADSWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Serial.
/* #undef HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_SERIALWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE

#endif /* TPETRACLASSIC_DEFAULTNODE_CONFIG_H */

==> trilinos-12.12.1-4-x86_64.pkg.tar.xz: usr/include/KokkosClassic_DefaultNode_config.h <==
#ifndef TPETRACLASSIC_DEFAULTNODE_CONFIG_H
#define TPETRACLASSIC_DEFAULTNODE_CONFIG_H

// Tpetra's default Node type.
#define TPETRA_DEFAULTNODE Kokkos::Compat::KokkosSerialWrapperNode
// For backwards compatibility ONLY.
#define KOKKOSCLASSIC_DEFAULTNODE TPETRA_DEFAULTNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Cuda.
/* #undef HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_CUDAWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_CUDAWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::OpenMP.
/* #undef HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_OPENMPWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_OPENMPWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Threads.
/* #undef HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE */
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_THREADSWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_THREADSWRAPPERNODE

// Defined if and only if Tpetra's default execution space is Kokkos::Serial.
#define HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE
// For backwards compatibility ONLY.
#ifdef HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE
#  define HAVE_KOKKOSCLASSIC_DEFAULTNODE_SERIALWRAPPERNODE 1
#endif // HAVE_TPETRA_DEFAULTNODE_SERIALWRAPPERNODE

#endif /* TPETRACLASSIC_DEFAULTNODE_CONFIG_H */
